\name{krige.bayes}

\alias{krige.bayes}
\alias{krige.bayes.predict}
\alias{krige.bayes.aux1}
\alias{krige.bayes.aux2}
\alias{krige.bayes.aux3}
\alias{krige.bayes.aux5}
\alias{krige.bayes.aux6}
\alias{krige.bayes.aux10}
\alias{krige.bayes.aux11}
\alias{krige.bayes.aux12}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Function to performing Bayesian geostatistical analysis}

\description{
  This function performs Bayesian analysis of geostatistical data.
  Samples from the posterior distributions for the model parameters are
  provided as well as summaries statistics: posterior mean, mode and
  medians. If prediction locations are provided, samples from the
  predictive distributions are also returned.
}
\usage{
krige.bayes(geodata, coords=geodata$coords, data=geodata$data, locations = "no", trend.d = "cte", trend.l = "cte",
	beta.prior = "flat", beta = NULL, beta.var = NULL, sill.prior = T,
         sill = NULL, 
         range = NULL, range.prior = c("squared.reciprocal",
	"reciprocal", "uniform", "exponential", "fixed"), exponential.prior.par = 1,
	range.limits = "default", cov.model = c("exponential", "matern", 
	"gaussian", "spherical", "cubic", "wave", "powered.exponential", 
	"cauchy", "gneiting", "gneiting.matern", "pure.nugget"), kappa = 0.5,
	nugget.prior = c("fixed", "uniform"), nugget = 0, lambda = 1, 
	aniso.pars = F, n.range = 51, n.posterior = 1000, distribution = T,
	mean.estimator = T, quantile.estimator = F, probability.estimator = F,
	messages.screen = T, signal = F, keep.for.prediction = T, moments = T,
	...)
}

%- maybe also `usage' for other objects documented here.
\section{Auxiliary functions}{
  The functions \code{krige.bayes.aux*} are auxiliary functions called by
  \code{krige.bayes}. The functions \link{\code{krige.bayes.predict}} is called
  is predictions locations are provided but can also be  directly invoked by
  the user.
}

\arguments{
  \item{geodata}{a list contanining elements \code{$coords} and
    \code{$data} as described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{a \emph{nx2} matrix where each row have the 2-D
    coordinates of the \emph{n} data locations.
    By default it takes the
    element \code{$coords} of the argument \code{geodata}, if this is provided.}
  \item{data}{a vector with \emph{n} data values. By default it takes the
    element \code{$data} of the argument \code{geodata}, is this is provided.}
  \item{locations}{a \emph{Nx2} matrix or data-frame with the 2-D
    coordinates of the \emph{N} locations to be predicted.
    Defaults to \code{"no"} in which case no prediction is
    performed and the function returns only posterior distributions for
    the model parameters.}
  \item{trend.d}{information about the trend (covariates) values at the data
    locations. Possible values are:
    \cr
    \code{"cte"} - model with constant mean, i.e. no trend
    \cr
    \code{"1st"} - trend is defined as a first degree polynomial on the coordinates
    \code{"2nd"} - trend is defined as a second degree polynomial on the
    coordinates
    \cr a formula of the type \code{~X}, where \code{X} is a matrix with covariates (external trend)
    at data locations.
    \cr
    Defaults to \code{"cte"}.}
  \item{trend.l}{Specifies the trend (covariate) at prediction
    locations. Must be the same type as defined in \code{trend.d}.
    Needed only of prediction locations are provided in the argument
    \code{locations}.}
  \item{beta.prior}{prior distribution for the mean (vector)
    parameter \eqn{\beta}. The options are "flat" (default), "normal" or "deg"
    (degenerated - known mean).}
  \item{beta}{hyperparameter for the distribution of the mean (vector) parameter
    \eqn{\beta}. Needed only if \code{beta.prior = "normal"} or
    \code{beta.prior = "deg"}. For the later \code{beta} defines the value of
    the known mean.}
  \item{beta.var}{(co)variance hyperparameters for the prior of the mean
    (vector) parameter \eqn{\beta}. Needed only if \code{beta.prior = "normal"}.}
  \item{sill.prior}{\code{TRUE} (default) or \code{FALSE}, specifying
    whether or not the \emph{sill} parameter \eqn{\sigma^2} is regarded as random during
    analysis. If \code{TRUE}, the prior assigned is \eqn{\frac{1}{\sigma^2}}.}
  \item{sill}{values of the sill parameter \eqn{\sigma^2}. Needed only if
    \code{sill.prior = FALSE}.}
  \item{range.prior}{prior distribution for the range parameter
    \eqn{\phi}. Allowed values are \code{"squared.reciprocal"} (\eqn{\frac{1}{\phi^2}}),
    \code{"reciprocal"}  (\eqn{\frac{1}{\phi}}), \code{"uniform"}
    (\eqn{\propto 1}), \code{"exponential"} (\eqn{\exp(-\nu *
      \phi)}), \code{"fixed"} (known \eqn{\phi}). If the latter is
    defined the parameter \eqn{\phi} is considered as known when preforming
    prediction.}
  \item{exponential.prior.par}{parameter \eqn{\nu} for the exponential
    prior for the parameter \eqn{phi}. Needed only if \code{prior.phi = "exponential"}.}
  \item{range.limits}{support values for the discretisation of the prior
    for the range parameter \eqn{\phi}.}
  \item{n.range}{number of points in the discrete priot distribution of
    \eqn{\phi}. If \code{range.limits} is a vector with 2 values these
    values are used to construct a sequence of values of length
    \code{n.range}, otherwise it is ignored.}
  \item{range}{known range parameter for predictions. Needed only if
    \code{range.prior = "fixed"}.}
  \item{cov.model}{model for the correlation function. See options in the
    function call and/or documentation for the function \link{\code{cov.spatial}}. }
  \item{kappa}{extra parameter needed for some of the correlation
    functions: (\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}). For more details see documentation for the
    function \link{\code{cov.spatial}}. This parameter is always regarded
    as fixed during the Bayesian analysis.}
  \item{nugget.prior}{specifies a prior distribution for the nugget
    parameter \eqn{\tau^2}. If \code{prior.nugget = "fixed"} the nugget is
    considered known (fixed) with value given by the argument
    \code{nugget}.
    If \code{prior.nugget = "uniform"} a discrete uniform prior is used
    with support points given by the argument \code{nugget}.}
  \item{nugget}{fixed (known) values for the nugget parameter (if
    \code{prior.nugget = "uniform"}) or a sequence of values defining the
    support points for the relative nugget \eqn{\frac{\tau^2}{\sigma^2}}.}
  \item{lambda}{Box-Cox transformation parameter. If \code{lambda = 1} no
    transformation is done, otherwise the Box-Cox data transformation is
    done before the analysis. The transformation parameter \eqn{\lambda}
    is regarded as a fixed parameter during the Bayesian analysis.
    The results are in the same scale as the original data.
    If \code{lambda=0} the log-transformation is performed.
    If \eqn{\code{lambda} < 0} the mean predictor doesn't make sense
    (the resulting distribution has no expectation). }
  \item{aniso.pars}{fixed parameters for geometric anisotropy
    correction. If \code{aniso.pars = F} no correction is done otherwise
    a vector with 2 values, anisotropy angle and ratio of ranges, must be provided}
  \item{n.posterior}{number of samples taken from the posterior and
    predictive distributions.}
  \item{distribution}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not the samples of the predictive distributions must be
    kept.
    Only used prediction locations are provided on the argument \code{locations}.}
  \item{mean.estimator}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not the mean and variances of the predictive distributions must be
    computed and kept. If \code{TRUE} objects \code{predict.mean} and
    \code{krige.var} are included in the output.
    Only used prediction locations are provided on the argument \code{locations}.}
  \item{quantile.estimator}{indicates
    whether or not quantiles of the predictive distributions must be
    computed and kept. If a vector with numbers in the interval
    \eqn{\[0,1\]} is provided the corresponding quantile(s) estimators
    are included in the output in the object \code{quantiles}. For
    example, if \code{estimator = c(0.25,0.50,0.75)} the function
    returns the 1st quartile, median and 3rd quartile for each location.
    If \code{TRUE}, the default is the vector c(0.025, 0.5, 0.975)
    and an uncertainty measure which is an analogy to the kriging
    standard error can be computed by \eqn{(q0.975 - q0.025)/4}.
    Only used prediction locations are provided on the argument \code{locations}.}
  \item{probability.estimator}{the default is \code{FALSE}. If some
    cutoff values are provided instead, an object called
    \code{probability} is included in the output providing, for each
    location, wthe probability of the variable be less or equal than the
    cutoff value given by the argument.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printend on the screen (or output file)
    while the function is running.}
  \item{signal}{if \code{TRUE} the signal is predict, otherwise the
    variable is predict. If no transformation is performed the
    expectations are the same in both cases and the difference is only in
    the kriging variance, if nugget is different form zero.}
  \item{keep.for.prediction}{if \code{TRUE} partial compution results are
    stored to be used for the function \code{krige.bayes.predict}. Typicaly
    \code{krige.bayes} can be once and \code{krige.bayes.predict} is run later
    with different prediction grids and or number of samples in the
    predictive distribution.}
  \item{moments}{if \code{TRUE} moments of the predictive distribution
    are computed without sampling. This works only if \code{lambda = 1}
    or \code{lambda = 0}.}
}

\details{
  \code{krige.bayes} is a generic function for geostatistical Bayesian
  prediction which includes parameter uncertainty.
  It can also be set to run conventional kriging methods which
  uses known parameters or \emph{plug-in} estimates although the
  functions \cpde{krige.conv} and \code{ksline} are more suitable fot
  that.
  The basis for the Bayesian algorithm is to use a discrete prior
  distribution for the parameters \eqn{\phi} and \eqn{\tau^2_{rel} =
    \frac{tau^2}{\sigma^2}}. See the Tech. Report below for further information.
}
\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
  ...
}
\references{Ribeiro, P.J. Jr. and Diggle, P.J. (1999) \emph{Bayesian
    inference in Gaussian model-based geostatistics}. Tech. Report
  ST-99-08, Depto Maths and Stats, Lancaster University.\cr
  Available at: 
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geostats.html}
}

\author{Paulo J. Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}.
}

\seealso{\code{\link{lines.krige.bayes}}, \code{\link{krige.conv}},
  \code{\link{ksline}}}


\examples{
# creating a simulated data-set
ex.data <- grf(70, cov.pars=c(10, .25), nugget=4)
#
# defining the prediction grid:
ex.grid <- as.matrix(expand.grid(seq(0,1,l=6), seq(0,1,l=6)))
#
# computing Bayesian posteriors and predictive distributions  
ex.bayes <- krige.bayes(ex.data, ex.data, loc=ex.grid,
range.limits=seq(0, 2, l=11), info.for.prediction = T)
#
# predictiong again in a fines grid and more sample in the predictive distribution
ex.grid1 <- as.matrix(expand.grid(seq(0,1,l=11), seq(0,1,l=11)))
ex.bayes1 <- krige.bayes.predict(loc = ex.grid1, trend.l="cte", info =
ex.bayes$info.for.prediction, signal = T, n.predictive = 500)
}

\keyword{spatial}

