\name{likfit}

\alias{likfit}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{ML/REML estimation of parameters of a (transformed) Gaussian random field}

\description{
  This function estimates parameters of a (trensformed) Gaussian random field using
  either \emph{maximum likelihood} (ML) or \emph{restricted maximum
    likelihood}. It includes the possibility of estimate the  Box-Cox's transformation parameter.
}

\usage{
likfit(geodata, coords=geodata$coords, data=geodata$data, ini,
trend = "cte", vcov = F, 
          hessian = F, fix.nugget = F, nugget = 0, method = "ML", 
          cov.model = c("matern", "exponential", "gaussian", "spherical",
            "cubic", "wave", "powered.exponential", "cauchy", "gneiting", 
            "gneiting.matern", "pure.nugget"), kappa = 0.5,
          fix.lambda = TRUE, lambda = 1,
          predicted = FALSE, residuals = FALSE, messages.screen = TRUE, 
          automatic.refit = T, min.func= c("nlmP", "nlm"),
          range.limits = "default", ...) 
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list contanining elements \code{coords} and
    \code{$data} described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{ a \emph{nx2} matrix contanining in each row euclidian
    coordinates of the \emph{n} data locations. By default it takes the
    element \code{$coords} of the argumentb \code{geodata}.}
  \item{data}{a vector with data values. By default it takes the
    element \code{$data} of the argumentb \code{geodata}.}
  \item{ini}{initial values of the covariance parameters. These values
    are used to initiate the numerical minimiser. If the model to be
    fitted has 3 parameters: nugget (\eqn{\tau^2}), sill (\eqn{\sigma^2})
    and range (\eqn{\phi}), \code{ini} is a vector with initial values for
    these tree paramaters. If the model to be fitted does not have has
    nugget \code{ini} is a vector with 2 components, the initial values for
    \eqn{sigma^2} and \eqn{phi}. If \code{ini} is a matrix with several
    initial values on the rows a serch for the better initial value is
    performed. The values of the likelihood function is computed for each of
    them and the row with maximum value is used to initiate the numarical maximasation.}
  \item{trend}{specifies the mean part of the model. The options are:
    \code{"cte"} (constant mean - default option), \code{"1st"} (a first degree polynomial
    on the coordinates), \code{"2nd"} (a second degree polynomial
    on the coordinates), or a formula of the type \code{~X} where \code{X}
    is a matrix with the covariates (external trend). }
  \item{fix.nugget}{A flag indication whether or not the nugget parameter
    must be included in the estimation. If \code{fix.nugget = T} the
    argument \code{ini} must be a vector of length 2 or a matrix with 2 columns}
  \item{nugget}{Value of the nugget parameter when \code{fix.nugget = TRUE}. The default is 0.}
  \item{method}{\code{ML} for maximum likelihood or \code{REML} for restricted maximum likelihood.}
  \item{cov.model}{model for the correlation function. See options in the
    function call and/or documentation for the function \link{\code{cov.spatial}}. }
  \item{kappa}{extra parameter needed for some of the correlation
    functions: (\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}). For more details see documentation for the
    function \link{\code{cov.spatial}}. This parameter is always regarded
    as fixed during the ML/REML parameter estimation.}
  \item{fix.lambda}{If \code{TRUE} (default option) the transformation parameter is regarded as fixed (known) during the estimation process otherwise the ML/REML for this parameter is also computed.}
  \item{lambda}{Box-Cox transformation parameter. Two particular cases are \code{lambda = 1} which corresponds to no
    transformation and \code{lambda=0} corresponding to the log-transformation.    The value of the transformation parameter \eqn{\lambda} is regarded as a fixed value for the parameter if \code{fix.lambda = TRUE} or is used as a initial value in the search if  \code{fix.lambda = FALSE}.}
  \item{predicted}{predicted values at the data locations}
  \item{residuals}{residuals at the data locations}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printend on the screen (or output file)
    while the function is running.}
  \item{automatic.refit}{ ~~Describe \code{automatic.refit} here~~ }
  \item{min.func}{minimisation function to be used}
  \item{range.limits}{minimum and maximum values allowed for the correlation function parameter (range). The defalt -s \code{c(0, +Inf)}.}
  \item{\dots}{additional parameters to be passed to the minimisation function}
}
%\details{
% ~~ If necessary, more details than the __description__  above ~~
%}

\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
  ...
}
%\references{ ~put references to the literature/web site here ~ }

\author{Paulo Justiniano Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}.}

%\note{ ~~further notes~~ }

 ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{olsfit}}, \code{\link{wlsfit}}, 
	\code{\link{plot.variogram}}, \code{\link{lines.variogram}},
  	\code{\link{lines.variomodel}}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	     or do  help(data=index)  for the standard data sets.
}

\keyword{spatial}%-- one or more ...
